import time
import copy
from lxml import html
import numpy as np
import pandas as pd
import requests
from bs4 import BeautifulSoup
from datetime import datetime, timedelta

class BenzingaScraper:
    def __init__(self, lookback, nb_pages):
        self.lookback = lookback
        self.nb_pages = nb_pages
        self.min_date = datetime.today() - timedelta(days=lookback)
        
    def get_news_data(self, stock):
        keep_going = True
        page_nb = 0
        benzinga_news = pd.DataFrame()
        try:
            while (page_nb<self.nb_pages and keep_going):
                URL = 'https://www.benzinga.com/stock-articles/{}/all?page={}'.format(stock, page_nb)
                page = requests.get(URL)
                soup = BeautifulSoup(page.content, "html.parser")
                view_content = soup.find_all("div", class_="view-content")[0]
                item_list = view_content.find_all("div", class_="item-list")
                for item in item_list:
                    date = item.find_all("h3")[0].text
                    date_parsed = datetime.strptime(date, '%A, %B %d, %Y')
                    if date_parsed < self.min_date:
                        keep_going = False
                        break
                    articles = item.find_all("span", class_="field-content")
                    for article in articles:
                        headline = article.find_all("a")[0]
                        href = headline["href"]
                        title = headline.text
                        benzinga_news = benzinga_news.append(pd.DataFrame({'date': [date_parsed], 
                                                                          'url': ['http://www.benzinga.com' + href],
                                                                          'title': [title]}))
                page_nb = page_nb + 1
        except:
            print('no news for ' + stock)
        return benzinga_news